Index: trunk/src/org/openstreetmap/josm/gui/MainApplication.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MainApplication.java	(revision 17797)
+++ trunk/src/org/openstreetmap/josm/gui/MainApplication.java	(revision 17798)
@@ -1034,4 +1034,6 @@
         // Disable automatic POST retry after 5 minutes, see #17882 / https://bugs.openjdk.java.net/browse/JDK-6382788
         Utils.updateSystemProperty("sun.net.http.retryPost", "false");
+        // Force text antialiasing, not including mappaint text
+        Utils.updateSystemProperty("awt.useSystemAAFontSettings", "on");
     }
 
Index: trunk/src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java	(revision 17797)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java	(revision 17798)
@@ -4,4 +4,7 @@
 import java.awt.Color;
 import java.awt.Font;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.RenderingHints;
 import java.io.IOException;
 import java.io.InputStream;
@@ -22,6 +25,7 @@
 
 /**
  * Subclass of {@link JEditorPane} that adds a "native" context menu (cut/copy/paste/select all)
  * and effectively uses JOSM user agent when performing HTTP request in {@link #setPage(URL)} method.
  * @since 5886
  */
@@ -85,4 +89,14 @@
         }
         return conn.getContent();
+    }
+
+    @Override
+    public void paintComponent(Graphics g) {
+        // Force antialiasing within the JosmEditorPane for antialiased bullet points
+        Graphics2D g2d = (Graphics2D) g.create();
+        g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
+        g2d.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
+        super.paintComponent(g2d);
+        g2d.dispose();
     }
 
@@ -22,6 +25,7 @@
 
 /**
- * Subclass of {@link JEditorPane} that adds a "native" context menu (cut/copy/paste/select all)
- * and effectively uses JOSM user agent when performing HTTP request in {@link #setPage(URL)} method.
+ * Subclass of {@link JEditorPane} that adds a "native" context menu (cut/copy/paste/select all), forces text and bullet
+ * point antialiasing based on user preferences, and effectively uses JOSM user agent when performing HTTP request in
+ * {@link #setPage(URL)} method.
  * @since 5886
  */
